@@ -186,32 +186,6 @@ class Module:
         self.build_battery_page()
         self.csd_power_proxy.connect("g-properties-changed", self.build_battery_page)
 
-        primary_output = None
-        try:
-            screen = CinnamonDesktop.RRScreen.new(Gdk.Screen.get_default())
-            outputs = CinnamonDesktop.RRScreen.list_outputs(screen)
-            for output in outputs:
-                if (output.is_connected() and output.is_laptop()):
-                    try:
-                        # Try to get the backlight info, if it fails just move on (we used to rely on output.get_backlight_min() and output.get_backlight_max() but these aren't reliable)
-                        output.get_backlight()
-                        primary_output = output
-                        break
-                    except:
-                        pass
-        except Exception as detail:
-            print("Failed to query backlight information in cs_power module: %s" % detail)
-
-        if primary_output is None:
-            if self.show_battery_page:
-                self.sidePage.add_widget(self.sidePage.stack)
-                self.sidePage.stack.add_titled(power_page, "power", _("Power"))
-                self.sidePage.stack.add_titled(self.battery_page, "batteries", _("Batteries"))
-            else:
-
-                self.sidePage.add_widget(power_page)
-            return
-
         proxy = Gio.DBusProxy.new_sync(
             Gio.bus_get_sync(Gio.BusType.SESSION, None),
             Gio.DBusProxyFlags.NONE,
@@ -223,7 +197,9 @@ class Module:
 
         try:
             brightness = proxy.GetPercentage()
-        except:
+        except GLib.Error as e:
+            print("Power module brightness page not available: %s" % e.message)
+
             if self.show_battery_page:
                 self.sidePage.add_widget(self.sidePage.stack)
                 self.sidePage.stack.add_titled(power_page, "power", _("Power"))
@@ -242,7 +218,7 @@ class Module:
             size_group = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
 
             section = page.add_section(_("Screen brightness"))
-            section.add_row(BrightnessSlider(section, proxy))
+            section.add_row(BrightnessSlider(section, proxy, _("Screen brightness")))
 
             section.add_row(GSettingsSwitch(_("On battery, dim screen when inactive"), CSD_SCHEMA, "idle-dim-battery"))
 
@@ -250,6 +226,22 @@ class Module:
 
             section.add_reveal_row(GSettingsComboBox(_("Dim screen after inactive for"), CSD_SCHEMA, "idle-dim-time", IDLE_DELAY_OPTIONS, valtype=int, size_group=size_group), CSD_SCHEMA, "idle-dim-battery")
 
+            proxy = Gio.DBusProxy.new_sync(Gio.bus_get_sync(Gio.BusType.SESSION, None),
+                                           Gio.DBusProxyFlags.NONE,
+                                           None,
+                                           "org.cinnamon.SettingsDaemon.Power",
+                                           "/org/cinnamon/SettingsDaemon/Power",
+                                           "org.cinnamon.SettingsDaemon.Power.Keyboard",
+                                           None)
+
+            try:
+                brightness = proxy.GetPercentage()
+            except GLib.Error as e:
+                print("Power module no keyboard backlight: %s" % e.message)
+            else:
+                section = page.add_section(_("Keyboard backlight"))
+                section.add_row(BrightnessSlider(section, proxy, _("Backlight brightness")))
+
     def build_battery_page(self, *args):
 
         self.aliases = {}
@@ -582,7 +574,7 @@ def get_available_options(up_client):
 class BrightnessSlider(SettingsWidget):
     step = 5
 
-    def __init__(self, section, proxy):
+    def __init__(self, section, proxy, label):
         super(BrightnessSlider, self).__init__()
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_spacing(0)
@@ -593,7 +585,7 @@ class BrightnessSlider(SettingsWidget):
 
         hbox = Gtk.Box()
 
-        self.label = Gtk.Label.new(_("Screen brightness"))
+        self.label = Gtk.Label.new(label)
         self.label.set_halign(Gtk.Align.CENTER)
 
         self.min_label= Gtk.Label()
